<?xml version="1.0" ?><!DOCTYPE TS><TS language="lv" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About %1</source>
        <translation>Par %1</translation>
    </message>
    <message>
        <source>&lt;h2&gt;%1 Client %2&lt;/h2&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;h5&gt; REV %1 &lt;/h5&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>About</source>
        <translation>Par</translation>
    </message>
    <message>
        <source>Check For Updates</source>
        <translation>Meklēt atjauninājumus</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
</context>
<context>
    <name>AccountManager</name>
    <message>
        <source>failed to open account database</source>
        <translation>neizdevās atvērt kontu datubāzi</translation>
    </message>
    <message>
        <source>Authorization expired, please re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to remove local repos sync token: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo sync information from server: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccountSettingsDialog</name>
    <message>
        <source>Account Settings</source>
        <translation>Konta iestatījumi</translation>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation>Lūdzu, ievadiet servera adresi</translation>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation>%1 nav derīga servera adrese</translation>
    </message>
    <message>
        <source>Failed to save account information</source>
        <translation>Neizdevās saglabāt konta informāciju</translation>
    </message>
    <message>
        <source>Failed to save the changes: %1</source>
        <translation>Neizdevās saglabāt izmaiņas: %1</translation>
    </message>
    <message>
        <source>Successfully updated current account information</source>
        <translation>Veiksmīgi atjaunināta pašreizējā konta informācija</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Server Address</source>
        <translation>Servera adrese</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>E-pasts</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>AccountView</name>
    <message>
        <source>Are you sure you want to remove account %1?&lt;br&gt;&lt;br&gt;The account will be removed locally. All syncing configuration will be removed too. The account at the server will not be affected.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync libraries of this account: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>click to open the website</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>pro version</source>
        <translation>pro versija</translation>
    </message>
    <message>
        <source>No account</source>
        <translation>Nav konta</translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Izvēlēties</translation>
    </message>
    <message>
        <source>Account settings</source>
        <translation>Konta iestatījumi</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Pieslēgties</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Pievienot kontu</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Atteikties</translation>
    </message>
    <message>
        <source>not logged in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>Account</source>
        <translation>Konts</translation>
    </message>
    <message>
        <source>email</source>
        <translation>e-pasts</translation>
    </message>
    <message>
        <source>server</source>
        <translation>serveris</translation>
    </message>
</context>
<context>
    <name>ActivitiesTab</name>
    <message>
        <source>File Activities are only supported in %1 Server Professional Edition.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>atkārtot</translation>
    </message>
    <message>
        <source>Failed to get actvities information. Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoUpdateManager</name>
    <message>
        <source>Upload Success</source>
        <translation>Augšupielāde veiksmīga</translation>
    </message>
    <message>
        <source>File &quot;%1&quot;
uploaded successfully.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot;
failed to upload.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The file is locked by %1, please try again later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload Failure: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AvatarService</name>
    <message>
        <source>Failed to create avatars folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CheckRepoRootDirPermDialog</name>
    <message>
        <source>Checking Permission</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneTasksDialog</name>
    <message>
        <source>Download tasks</source>
        <translation>Lejupielādēt uzdevumus</translation>
    </message>
    <message>
        <source>remove all successful tasks</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No download tasks right now.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Notīrīt</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableModel</name>
    <message>
        <source>Library</source>
        <translation>Bibliotēka</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Ceļš</translation>
    </message>
</context>
<context>
    <name>CloneTasksTableView</name>
    <message>
        <source>Cancel this task</source>
        <translation>Atcelt šo uzdevumu</translation>
    </message>
    <message>
        <source>cancel this task</source>
        <translation>atcelt šo uzdevumu</translation>
    </message>
    <message>
        <source>Remove this task</source>
        <translation>Dzēst šo uzdevumu</translation>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation>Neizdevās atcelt šo uzdevumu:

 %1</translation>
    </message>
    <message>
        <source>Failed to remove this task:

 %1</source>
        <translation>Neizdevās dzēst šo uzdemumu:

 %1</translation>
    </message>
</context>
<context>
    <name>CloudView</name>
    <message>
        <source>Minimize</source>
        <translation>Minimizēt</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
    <message>
        <source>Libraries</source>
        <translation>Bibliotēkas</translation>
    </message>
    <message>
        <source>Starred</source>
        <translation>Favorīti</translation>
    </message>
    <message>
        <source>Activities</source>
        <translation> Aktivitātes</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Meklēt</translation>
    </message>
    <message>
        <source>current download rate</source>
        <translation>pašreizējais lejupielādes ātrums</translation>
    </message>
    <message>
        <source>current upload rate</source>
        <translation>pašreizējais augšupielādes ātrums</translation>
    </message>
    <message>
        <source>Please Choose a folder to sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>no server connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>all servers connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Form</source>
        <translation>Forma</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>emblēma</translation>
    </message>
    <message>
        <source>minimize</source>
        <translation>minimizēt</translation>
    </message>
    <message>
        <source>close</source>
        <translation>aizvērt</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Select</source>
        <translation>Atlasīt</translation>
    </message>
    <message>
        <source>brand</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or Drop Folder to Sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>download rate</source>
        <translation>lejupielādes ātrums</translation>
    </message>
    <message>
        <source>downarrow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>upload rate</source>
        <translation>augšupielādes ātrums</translation>
    </message>
    <message>
        <source>uparrow</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Configurator</name>
    <message>
        <source>Error when creating ccnet configuration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create preconfigure directory &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to read %1</source>
        <translation>neizdevās nolasīt %1</translation>
    </message>
</context>
<context>
    <name>CreateRepoDialog</name>
    <message>
        <source>Create a library</source>
        <translation>Izveidot bibliotēku</translation>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating...</source>
        <translation>Izveido...</translation>
    </message>
    <message>
        <source>Failed to generate encryption key for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose the directory to sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the name</source>
        <translation>Lūdzu, ievadiet vārdu</translation>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lūdzu, ievadiet paroli</translation>
    </message>
    <message>
        <source>Passwords don&apos;t match</source>
        <translation>Paroles nesakrīt</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nezināma kļūda</translation>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create library on the server:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation>Ceļš: </translation>
    </message>
    <message>
        <source>Choose</source>
        <translation>Izvēlēties</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Vārds: </translation>
    </message>
    <message>
        <source>encrypted</source>
        <translation>šifrēts</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parole: </translation>
    </message>
    <message>
        <source>Password Again:</source>
        <translation>Parole vēlreiz: </translation>
    </message>
    <message>
        <source>status text</source>
        <translation>statusa teksts</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>DaemonManager</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 client failed to initialize</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DownloadRepoDialog</name>
    <message>
        <source>Please enter the password</source>
        <translation>Lūdzu, ievadiet paroli</translation>
    </message>
    <message>
        <source>Sync library &quot;%1&quot;</source>
        <translation>Sinhronizēt bibliotēku &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync folder &quot;%1&quot;</source>
        <translation>Sinhronizēt mapi &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Sync to folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>or</source>
        <translation>vai</translation>
    </message>
    <message>
        <source>sync with an existing folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>create a new sync folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync with this existing folder:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a folder</source>
        <translation>Lūdzu, izvēlieties mapi</translation>
    </message>
    <message>
        <source>The folder does not exist</source>
        <translation>Mape neeksistē</translation>
    </message>
    <message>
        <source>Please choose the folder to sync.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your organization disables putting a library outside %1 folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing file &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflicting with existing library &quot;%1&quot;, please choose a different folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder &quot;%1&quot; already exists. Are you sure to sync with it (contents will be merged)?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Click No to sync with a new folder instead</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to find an alternative folder name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to add download task:
 %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get repo download information:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download Library</source>
        <translation>Lejupielādēt bibliotēku</translation>
    </message>
    <message>
        <source>choose...</source>
        <translation>izvēlieties...</translation>
    </message>
    <message>
        <source>Password for this library:</source>
        <translation>Parole šai bibliotēkai:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>EventDetailsDialog</name>
    <message>
        <source>Modification Details</source>
        <translation>Izmaiņu detaļas</translation>
    </message>
</context>
<context>
    <name>EventDetailsListModel</name>
    <message>
        <source>Added files</source>
        <translation>Pievienot datnes</translation>
    </message>
    <message>
        <source>Deleted files</source>
        <translation>Dzēst datnes</translation>
    </message>
    <message>
        <source>Modified files</source>
        <translation>Modificēt datnes</translation>
    </message>
    <message>
        <source>Added folders</source>
        <translation>Pievienot mapes</translation>
    </message>
    <message>
        <source>Deleted folders</source>
        <translation>Dzēst mapes</translation>
    </message>
</context>
<context>
    <name>EventDetailsListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Atvērt</translation>
    </message>
    <message>
        <source>Open &amp;parent folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserDialog</name>
    <message>
        <source>Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation>Atpakaļ</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Uz priekšu</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Mājas</translation>
    </message>
    <message>
        <source>Upload files</source>
        <translation>Augšupielādēt datnes</translation>
    </message>
    <message>
        <source>Upload a directory</source>
        <translation>Augšupielādēt mapes</translation>
    </message>
    <message>
        <source>You don&apos;t have permission to upload files to this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create a folder</source>
        <translation>Izveidot mapi</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Atjaunot</translation>
    </message>
    <message>
        <source>%1 items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder name</source>
        <translation>Mapes vārds</translation>
    </message>
    <message>
        <source>Invalid folder name!</source>
        <translation>Mapes vārds nederīgs!</translation>
    </message>
    <message>
        <source>The name &quot;%1&quot; is already taken.</source>
        <translation>Vārds &quot;%1&quot; ir jau aizņemts.</translation>
    </message>
    <message>
        <source>retry</source>
        <translation>atkārtot</translation>
    </message>
    <message>
        <source>Failed to get files information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This folder is empty.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter name of file to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter the path of the folder you want to save to...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do you want to overwrite the existing file &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; haven&apos;t been synced</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 already exists.&lt;br/&gt;Do you like to overwrite it?&lt;br/&gt;&lt;small&gt;(Choose No to upload using an alternative name).&lt;/small&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download file: %1</source>
        <translation>Neizdevās lejupielādēt failu: %1</translation>
    </message>
    <message>
        <source>Select a file to upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select a directory to upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename</source>
        <translation>Pārdēvēt</translation>
    </message>
    <message>
        <source>Do you really want to delete these items</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create folder failed</source>
        <translation>Izveidot mapi neizdevās</translation>
    </message>
    <message>
        <source>Lock file failed</source>
        <translation>Bloķēt failu neizdevās</translation>
    </message>
    <message>
        <source>Select a file to update %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Rename failed</source>
        <translation>Pārsaukt neizdevās</translation>
    </message>
    <message>
        <source>Remove failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share failed</source>
        <translation>Koplietot neizdevās</translation>
    </message>
    <message>
        <source>Cannot paste files from the same folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot paste the folder to its subfolder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy failed</source>
        <translation>Kopēt neizdevās</translation>
    </message>
    <message>
        <source>Move failed</source>
        <translation>Pārvietot neizdevās</translation>
    </message>
    <message>
        <source>Create library failed!</source>
        <translation>Izveidot bibliotēku neizdevās!</translation>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file %1: %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to create cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to open cache folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserProgressDialog</name>
    <message>
        <source>Pending</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Upload</source>
        <translation>Augšupielādēt</translation>
    </message>
    <message>
        <source>Uploading %1</source>
        <translation>Augšupielādē %1</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Lejupielādēt</translation>
    </message>
    <message>
        <source>Downloading %1</source>
        <translation>Lejupielādē %1</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 no %2</translation>
    </message>
    <message>
        <source>Failed to upload file &quot;%1&quot;, do you want to retry?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Abort</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Saving</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File save failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Last Modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Kind</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileBrowserSearchView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileNetworkTask</name>
    <message>
        <source>Operation canceled</source>
        <translation>Operācija atcelta</translation>
    </message>
    <message>
        <source>pending</source>
        <translation>gaida izpildi</translation>
    </message>
</context>
<context>
    <name>FileServerTask</name>
    <message>
        <source>task cancelled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Iekšējā servera kļūda</translation>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FileTableModel</name>
    <message>
        <source>locked by %1</source>
        <translation>Bloķējis %1</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Vārds</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Izmērs</translation>
    </message>
    <message>
        <source>Last Modified</source>
        <translation>Pēdējoreiz modificēts</translation>
    </message>
    <message>
        <source>Kind</source>
        <translation>Veids</translation>
    </message>
</context>
<context>
    <name>FileTableView</name>
    <message>
        <source>&amp;Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation>Pārdēvēt</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Dzēst</translation>
    </message>
    <message>
        <source>Share to Group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Update</source>
        <translation>Atjaunot</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Kopēt</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Izgriezt</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Ielīmēt</translation>
    </message>
    <message>
        <source>Canc&amp;el Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Sync this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This feature is available in pro version only
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Generate %1 Download Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>G&amp;enerate %1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Save As To...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Un&amp;lock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to remove readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to cut readonly files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retry Upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Delete Local Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Version Save As...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open Local Cache Folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GetFileTask</name>
    <message>
        <source>Failed to create folders</source>
        <translation>Neizdevās izveidot mapes</translation>
    </message>
    <message>
        <source>Failed to create temporary files</source>
        <translation>Neizdevās izveidot pagaidu datnes</translation>
    </message>
    <message>
        <source>Failed to write file to disk</source>
        <translation>Neizdevās ierakstīt datni diskā</translation>
    </message>
    <message>
        <source>Failed to remove the older version of the downloaded file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to move file</source>
        <translation>Neizdevās pārvietot datni</translation>
    </message>
</context>
<context>
    <name>InitSeafileDialog</name>
    <message>
        <source>%1 Initialization</source>
        <translation>%1 inicializēšana</translation>
    </message>
    <message>
        <source>Choose %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please choose a directory</source>
        <translation>Lūdzu, izvēlieties mapi</translation>
    </message>
    <message>
        <source>Initialization is not finished. Really quit?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The folder %1 does not exist</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>emblēma</translation>
    </message>
    <message>
        <source>Choose a folder</source>
        <translation>Izvēlieties mapi</translation>
    </message>
    <message>
        <source>Please choose a folder. We will create a %1 subfolder in it. When you download a library, it will be saved there by default.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Izvēlēties...</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Nākošais</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>InitVirtualDriveDialog</name>
    <message>
        <source>%1 organizes files by libraries.
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Checking your default library...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating the default library...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create default library:

The server version must be 2.1 or higher to support this.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading default library...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download default library:
%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The default library has been downloaded.
You can click the &quot;Open&quot; button to view it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when downloading the default library: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to download default library:
 %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>%1 organizes files by libraries. 
Do you like to download your default library?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Skip</source>
        <translation>Izlaist</translation>
    </message>
    <message>
        <source>Run in Background</source>
        <translation>Izpildīt fonā</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Atvērt</translation>
    </message>
    <message>
        <source>Finish</source>
        <translation>Pabeigts</translation>
    </message>
    <message>
        <source>Download Default Library</source>
        <translation>Lejupielādēt noklusēto bibliotēku</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>emblēma</translation>
    </message>
</context>
<context>
    <name>LoadMoreButton</name>
    <message>
        <source>load more</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogDirUploader</name>
    <message>
        <source>Upload log files failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission Error!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library/Folder not found.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Authorization expired</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files failed :%1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Successfully uploaded log files</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogUploadProgressDialog</name>
    <message>
        <source>Compressing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LoginDialog</name>
    <message>
        <source>Add an account</source>
        <translation>Pievienot kontu</translation>
    </message>
    <message>
        <source>Single Sign On</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re-login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logging in...</source>
        <translation>Piesakos...</translation>
    </message>
    <message>
        <source>Network Error:
 %1</source>
        <translation>Tīkla kļūda:
 %1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the computer name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to save current account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Server Address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server address must not be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 is not a valid server address. It has to start with &apos;https://&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lūdzu, ievadiet paroli</translation>
    </message>
    <message>
        <source>Incorrect email or password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Logging in too frequently, please wait a minute</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal Server Error</source>
        <translation>Iekšējā servera kļūda</translation>
    </message>
    <message>
        <source>Failed to login: %1</source>
        <translation>Neizdevās pieteikties: %1</translation>
    </message>
    <message>
        <source>Failed to login</source>
        <translation>Neizdevās pieteikties</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>logo</source>
        <translation>emblēma</translation>
    </message>
    <message>
        <source>Server:</source>
        <translation>Serveris: </translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;For example: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Piemēram: https://seacloud.cc&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>or http://192.168.1.24:8000</source>
        <translation>vai http://192.168.1.24:8000</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parole: </translation>
    </message>
    <message>
        <source>status text</source>
        <translation>statusa teksts</translation>
    </message>
    <message>
        <source>Computer Name:</source>
        <translation>Datora vārds: </translation>
    </message>
    <message>
        <source>Email / Username:</source>
        <translation>E-pasts/Lietotajvārds</translation>
    </message>
    <message>
        <source>e.g. Jim&apos;s laptop</source>
        <translation>, piemēram, Džima klēpjdators</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Pieslēgties</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
    <message>
        <source>Automatic Login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LogoutView</name>
    <message>
        <source>You are logout. Please </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>login</source>
        <translation>pieslēgties</translation>
    </message>
    <message>
        <source>Add an account</source>
        <translation>Pievienot kontu</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Refresh</source>
        <translation>Atjaunot</translation>
    </message>
</context>
<context>
    <name>MessageListener</name>
    <message>
        <source>failed to load ccnet config dir </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; is unsynced. 
Reason: Deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; is synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files uploaded to &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File %1 conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by other application. This file will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync folder %1
Some file in this folder is locked by other application. This folder will be updated when you close the application.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path is ended with space or period and cannot be created on Windows.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync %1
File path contains invalid characters. It is not synced to this computer.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to index file %1
Please check file permission and disk space.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync. 
Access denied to service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; failed to sync.
The library owner&apos;s storage space is used up.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file %1 is denied by folder permission setting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync file %1
File is locked by another user. Update to this file is not uploaded.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PrivateShareDialog</name>
    <message>
        <source>Share %1</source>
        <translation>Koplietot %1</translation>
    </message>
    <message>
        <source>Enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enter user name or email address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Updated successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share Operation Failed: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removed successfully</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get share information of the folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to get your groups and contacts information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the username</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the group name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No such group &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to group %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Already shared to user %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share To:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Permission:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Write</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read-Only</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>indexing files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>downloading</source>
        <translation>lejupielādē</translation>
    </message>
    <message>
        <source>uploading</source>
        <translation>augšupielādē</translation>
    </message>
    <message>
        <source>sync merging</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>waiting for sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>server not connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>server authenticating</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>auto sync is turned off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unknown</source>
        <translation>nezināms</translation>
    </message>
    <message>
        <source>Server has been removed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have not logged in to the server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You do not have permission to access this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage space of the library owner has been used up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remote service is not available</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Access denied to service</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupted</source>
        <translation>Iekšējie dati bojāti</translation>
    </message>
    <message>
        <source>Failed to start upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occured in upload</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to start download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error occured in download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library is damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Conflict in merge</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server version is too old</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nezināma kļūda</translation>
    </message>
    <message>
        <source>Permission denied on server. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve proxy address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot resolve server address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cannot connect to server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to establish secure connection. Please check server SSL certificate</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer was interrupted. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Data transfer timed out. Please check network or firewall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unhandled http redirect from server. Please check server cofiguration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Server error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bad request</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal data corrupt on the client. Please try resync the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to write data on the client. Please check disk space or folder permissions</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Storage quota full</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library damaged on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The storage quota has been used up</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal server error</source>
        <translation>Iekšējā servera klūda</translation>
    </message>
    <message>
        <source>Your %1 client is too old</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Files are locked by other application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library is deleted on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when accessing the local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>initializing...</source>
        <translation>inicializēšana...</translation>
    </message>
    <message>
        <source>Failed to index local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to check server information</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to create local files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to merge local file changes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Incorrect password. Please download again</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>connecting server...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>indexing files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading file list...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloading files...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Creating folder...</source>
        <translation>Izveido mapi...</translation>
    </message>
    <message>
        <source>Merge file changes...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>checking server info...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Canceled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SSL Error</source>
        <translation>SSL kļūda</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Tīkla kļūda: %1</translation>
    </message>
    <message>
        <source>Server Error</source>
        <translation>Servera kļūda</translation>
    </message>
    <message>
        <source>failed to open certs database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File &quot;%1&quot; doesn&apos;t exist in &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 couldn&apos;t find an application to open file %2</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created library &quot;%1&quot;</source>
        <translation>Izveidota bibliotēka &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Deleted library &quot;%1&quot;</source>
        <translation>Dzēsta bibliotēka &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Rename %1 to</source>
        <translation>Pārsaukt %1 uz</translation>
    </message>
    <message>
        <source>Unable to download item &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>copy failed</source>
        <translation>kopēt neizdevās</translation>
    </message>
    <message>
        <source>Added</source>
        <translation>Pievienots</translation>
    </message>
    <message>
        <source>Deleted</source>
        <translation>Dzēsts</translation>
    </message>
    <message>
        <source>Removed</source>
        <translation>Noņemts</translation>
    </message>
    <message>
        <source>Modified</source>
        <translation>Modificēts</translation>
    </message>
    <message>
        <source>Renamed</source>
        <translation>Pārdēvēts</translation>
    </message>
    <message>
        <source>Added or modified</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Moved</source>
        <translation>Pārvietots</translation>
    </message>
    <message>
        <source>Added directory</source>
        <translation>Pievienota mape</translation>
    </message>
    <message>
        <source>Removed directory</source>
        <translation>Noņemta mape</translation>
    </message>
    <message>
        <source>Renamed directory</source>
        <translation>Pārsaukta mape</translation>
    </message>
    <message>
        <source>Moved directory</source>
        <translation>Pārvietota mape</translation>
    </message>
    <message>
        <source>files</source>
        <translation>datnes</translation>
    </message>
    <message>
        <source>directories</source>
        <translation>mapes</translation>
    </message>
    <message>
        <source>and %1 more</source>
        <translation>un %1 vairāk</translation>
    </message>
    <message>
        <source>Reverted library to status at</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reverted file &quot;%1&quot; to status at %2.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recovered deleted directory</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changed library name or description</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto merge by %1 system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Just now</source>
        <translation>Tagad</translation>
    </message>
    <message>
        <source>1 day ago</source>
        <translation>Pirms 1 dienas</translation>
    </message>
    <message>
        <source>%1 days ago</source>
        <translation>Pirms %1 dienām</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation>Pirms 1 stundas</translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>Pirms %1 stundām</translation>
    </message>
    <message>
        <source>1 minute ago</source>
        <translation>Pirms 1 minūtes</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>Pirms %1 minūtēm</translation>
    </message>
    <message>
        <source>&lt;Not Part of Certificate&gt;</source>
        <translation>&lt;Not Part of Certificate&gt;</translation>
    </message>
    <message>
        <source>Found another running process of %1, kill it and start a new one?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to start %1 due to the failure of shutting down the previous process</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this folder to:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder</source>
        <translation>Mape</translation>
    </message>
    <message>
        <source>Readonly Folder</source>
        <translation>Tikai lasāma mape</translation>
    </message>
    <message>
        <source>Document</source>
        <translation>Dokuments</translation>
    </message>
    <message>
        <source>PDF Document</source>
        <translation>PDF dokuments</translation>
    </message>
    <message>
        <source>Image File</source>
        <translation>Attēla datne</translation>
    </message>
    <message>
        <source>Text Document</source>
        <translation>Teksta dokuments</translation>
    </message>
    <message>
        <source>Audio File</source>
        <translation>Audio datne</translation>
    </message>
    <message>
        <source>Video File</source>
        <translation>Video datne</translation>
    </message>
    <message>
        <source>Word Document</source>
        <translation>Word dokuments</translation>
    </message>
    <message>
        <source>PowerPoint Document</source>
        <translation>PowerPoint dokuments</translation>
    </message>
    <message>
        <source>Excel Document</source>
        <translation>Excel dokuments</translation>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with system path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The path &quot;%1&quot; conflicts with an existing library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>uploading file list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Folder is locked by another application</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>File is locked by another user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path is invalid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error when indexing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path ends with space or period character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path contains invalid characters like &apos;|&apos; or &apos;:&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>failed to open file cache database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library name contains invalid characters such as &apos;:&apos;, &apos;*&apos;, &apos;|&apos;, &apos;?&apos;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Update to file denied by folder permission setting</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReliablePostFileTask</name>
    <message>
        <source>File does not exist</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoDetailDialog</name>
    <message>
        <source>Library &quot;%1&quot;</source>
        <translation>Bibliotēka &quot;%1&quot;</translation>
    </message>
    <message>
        <source>This library is not downloaded yet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error: </source>
        <translation>Kļūda:  </translation>
    </message>
    <message>
        <source>every %1 seconds</source>
        <translation>katras %1 sekundes</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>RepoIcon</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>RepoName</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Description:</source>
        <translation>Apraksts:</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Owner:</source>
        <translation>Īpašnieks: </translation>
    </message>
    <message>
        <source>Last Modified:</source>
        <translation>Pēdējoreiz modificēts:</translation>
    </message>
    <message>
        <source>mtime</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Size:</source>
        <translation>Izmērs: </translation>
    </message>
    <message>
        <source>Local Path:</source>
        <translation>Lokālais ceļš: </translation>
    </message>
    <message>
        <source>Status:</source>
        <translation>Statuss: </translation>
    </message>
    <message>
        <source>RepoStatus</source>
        <translation>Bibliotēkas statuss</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Vārds: </translation>
    </message>
    <message>
        <source>Sync Interval:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
</context>
<context>
    <name>RepoItemDelegate</name>
    <message>
        <source>, %1%2</source>
        <translation>, %1%2</translation>
    </message>
    <message>
        <source>, %1</source>
        <translation>, %1</translation>
    </message>
    <message>
        <source>This library has not been downloaded</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoService</name>
    <message>
        <source>Unable to open file &quot;%1&quot; from nonexistent library &quot;%2&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeModel</name>
    <message>
        <source>Recently Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>My Libraries</source>
        <translation>Manas bibliotēkas</translation>
    </message>
    <message>
        <source>Sub Libraries</source>
        <translation>Apakšbibliotēkas</translation>
    </message>
    <message>
        <source>Shared with me</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared with groups</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Synced Libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>sync initializing</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>RepoTreeView</name>
    <message>
        <source>Disable auto sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show &amp;details</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show details of this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recently Updated</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync &amp;now</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync this library immediately</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Cancel download</source>
        <translation>Atcelt lejupielādi</translation>
    </message>
    <message>
        <source>Cancel download of this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open folder</source>
        <translation>Atvērt mapi</translation>
    </message>
    <message>
        <source>open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open local folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Unsync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unsync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;View on cloud</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>view this library on seahub</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share to group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Share this library to a group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open cloud file browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open this library in embedded Cloud File Browser</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>leave share</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>unsync and resync this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set sync &amp;Interval</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>set sync interval for this library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to unsync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to resync the library &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure to overwrite the file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to unsync library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to leave the share &quot;%1&quot;?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Leaving share failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to cancel this task:

 %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The download has been canceled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You do not have permission to upload to this folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to overwrite file &quot;%1&quot; with itself</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to delete file &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to upload file: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sync Interval (In seconds):</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set Sync Internval For Library &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ReposTab</name>
    <message>
        <source>Search libraries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>atkārtot</translation>
    </message>
    <message>
        <source>Failed to get libraries information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileApiClient</name>
    <message>
        <source>&lt;b&gt;Warning:&lt;/b&gt; The ssl certificate of this server is not trusted, proceed anyway?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SeafileApplet</name>
    <message>
        <source>failed to add default account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed to initialize log: %s</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>SeafileLinkDialog</name>
    <message>
        <source>%1 Internal Link</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopēt uz starpliktuvi</translation>
    </message>
    <message>
        <source>%1 Web Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 Protocol Link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
</context>
<context>
    <name>SeafileRpcClient</name>
    <message>
        <source>failed to load ccnet config dir %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nezināma kļūda</translation>
    </message>
</context>
<context>
    <name>SeafileTrayIcon</name>
    <message>
        <source>Disable auto sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable auto sync</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Iziet</translation>
    </message>
    <message>
        <source>Show main window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Open %1 &amp;folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open &amp;logs folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show file sync errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Par</translation>
    </message>
    <message>
        <source>Show the application&apos;s About box</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Online help</source>
        <translation>Tiešsaistes palīdzība</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datne</translation>
    </message>
    <message>
        <source>auto sync is disabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uploading</source>
        <translation>Augšupielādē</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Lejupielādē</translation>
    </message>
    <message>
        <source>open %1 log folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>open %1 online help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>some servers not connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Upload log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>upload %1 log files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please login first</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchResultListView</name>
    <message>
        <source>&amp;Show in folder</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show in folder</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchTab</name>
    <message>
        <source>Search files</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>retry</source>
        <translation>atkārtot</translation>
    </message>
    <message>
        <source>Failed to search&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ServerStatusDialog</name>
    <message>
        <source>Servers connection status</source>
        <translation>Servera savienojuma statuss</translation>
    </message>
    <message>
        <source>connected</source>
        <translation>savienots</translation>
    </message>
    <message>
        <source>disconnected</source>
        <translation>atvienots</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Aizvērt</translation>
    </message>
</context>
<context>
    <name>SetRepoPasswordDialog</name>
    <message>
        <source>Please provide the library password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Provide the password for library %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the password</source>
        <translation>Lūdzu, ievadiet paroli</translation>
    </message>
    <message>
        <source>Incorrect password</source>
        <translation>Nepareiza parole</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Nezināma kļūda</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Iestatījumi</translation>
    </message>
    <message>
        <source>Auto start %1 after login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide %1 Icon from the dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>None</source>
        <translation>Neviens</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP starpniekserveris</translation>
    </message>
    <message>
        <source>Socks5 Proxy</source>
        <translation>Socks5 starpniekserveris</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have changed languange. Restart to apply it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy host address can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The proxy port is incorrect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy username can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Proxy password can&apos;t be empty</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Hide main window when started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Notify when libraries are synchronized</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable sync temporary files of MSOffice/Libreoffice</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Download speed limit (KB/s):</source>
        <translation>Lejupielādes ātruma limits (KB/s):</translation>
    </message>
    <message>
        <source>Upload speed limit (KB/s):</source>
        <translation>Augšupielādes ātruma limits  (KB/s):</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Pamata</translation>
    </message>
    <message>
        <source>Do not automatically unsync a library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not automatically unsync a library when its local directory is removed or unaccessible for other reasons.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not unsync a library when not found on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not automatically unsync a library when it&apos;s not found on server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable FinderSync Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable Explorer Extension</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Check for updates automatically</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not verify server certificate in HTTPS syncing</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable syncing with an existing folder with a different name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Uzlabot</translation>
    </message>
    <message>
        <source>Language (need restart)</source>
        <translation>Valoda (nepieciešama pārlāde)</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Valoda</translation>
    </message>
    <message>
        <source>Proxy Type:</source>
        <translation>Starpniekservera tips</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Port:</source>
        <translation>Ports:</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Lietotājvārds:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Parole: </translation>
    </message>
    <message>
        <source>Proxy server requires a password</source>
        <translation>Starpniekserveris prasa paroli</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Tīkls</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Atcelt</translation>
    </message>
</context>
<context>
    <name>SharedItemDelegate</name>
    <message>
        <source>Read Write</source>
        <translation>Lasīt/Rakstīt</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Tikai lasāms</translation>
    </message>
    <message>
        <source>Remove Share</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedItemsTableModel</name>
    <message>
        <source>Click to edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Created by %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Read Write</source>
        <translation>Lasīt/Rakstīt</translation>
    </message>
    <message>
        <source>Read Only</source>
        <translation>Tikai lasāms</translation>
    </message>
    <message>
        <source>Group</source>
        <translation>Grupa</translation>
    </message>
    <message>
        <source>User</source>
        <translation>Lietotājs</translation>
    </message>
    <message>
        <source>Permission</source>
        <translation>Atļauja</translation>
    </message>
    <message>
        <source>The previous operation is still in progres</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SharedLinkDialog</name>
    <message>
        <source>Share Link</source>
        <translation>Koplietot saiti</translation>
    </message>
    <message>
        <source>Share link:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Direct Download</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation>Kopēt uz starpliktuvi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Labi</translation>
    </message>
</context>
<context>
    <name>SslConfirmDialog</name>
    <message>
        <source>Untrusted Connection</source>
        <translation>Neuzticams savienojums</translation>
    </message>
    <message>
        <source>%1 uses an invalid security certificate. The connection may be insecure. Do you want to continue?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Current RSA key fingerprint is %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Previous RSA key fingerprint is %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Atcerēties manu izvēli</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
</context>
<context>
    <name>StarredFilesListView</name>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Atvērt</translation>
    </message>
    <message>
        <source>Open this file</source>
        <translation>Atvērt datni</translation>
    </message>
    <message>
        <source>view on &amp;Web</source>
        <translation>skatīt &amp;tīmeklī</translation>
    </message>
    <message>
        <source>view this file on website</source>
        <translation>Skatīt datni tīmeklī</translation>
    </message>
</context>
<context>
    <name>StarredFilesTab</name>
    <message>
        <source>retry</source>
        <translation>atkārtot</translation>
    </message>
    <message>
        <source>Failed to get starred files information&lt;br/&gt;Please %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>You have no starred files yet.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsDialog</name>
    <message>
        <source>File Sync Errors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>No sync errors.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SyncErrorsTableModel</name>
    <message>
        <source>Double click to open the library</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliotēka</translation>
    </message>
    <message>
        <source>Path</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation>Kļūda</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Laiks</translation>
    </message>
</context>
<context>
    <name>TwoFactorDialog</name>
    <message>
        <source>Enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Two Factor Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please enter the two factor authentication token</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dialog</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>mText</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember this device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UninstallHelperDialog</name>
    <message>
        <source>Uninstall %1</source>
        <translation>Atinstalēt %1</translation>
    </message>
    <message>
        <source>Do you want to remove the %1 account information?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Removing account information...</source>
        <translation>Noņemt konta informāciju...</translation>
    </message>
    <message>
        <source>Dialog</source>
        <translation>Dialoga logs</translation>
    </message>
    <message>
        <source>text</source>
        <translation>teksts</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Jā</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nē</translation>
    </message>
</context>
</TS>